@@ -16,5 +16,5 @@ sleep 1;
 say "Ha! Too slow!";
 cdio_close_tray undef, 0;
 
-sub fmax :Args(double, double) :Native :Returns(double) {warn "dude2"}
+sub fmax :Args(double, double) :Native :Returns(double) {}
 say "fmax(2.0, 3.0) = " . fmax(2.0, 3.0);
